DBSite — PyBSDDB 6.0.0 documentation

### Navigation

- index
- next |
- previous |
- PyBSDDB 6.0.0 documentation »

# DBSite

Read Oracle documentation for better understanding.

You use the DB_SITE handle to configure and manage replication sites.

More info...

## DBSite Methods

`close`(flags=0)

  Close a DBSite handle. More info...

`get_address`()

  Returns a replication site’s network address. That is, this method returns a tuple with the site’s hostname and port. More info...

`get_config`()

  Returns whether the specified which parameter is currently set. More info...

`get_eid`()

  Returns a replication site’s Environment ID (EID). More info...

`remove`()

  Removes the site from the replication group. If called at the master site, repmgr updates the membership database directly. If called from a client, this method causes a request to be sent to the master to perform the operation. The method then awaits confirmation. More info...

`set_config`(which, value)

  Configures a replication site. More info...

### Navigation

- index
- next |
- previous |
- PyBSDDB 6.0.0 documentation »